@@ -62,7 +62,7 @@ standardizedMRResiduals <- function(cube) {
     # calculate expected values
     E <- r * c / n
     # calculate variance
-    V <- r * c * (n - r) * (n - c) / n^3
+    V <- r * c * (n - r) * (n - c) / n^3 # nolint
     out <- (cube_array - E) / sqrt(V)
     if (is.array(out)) {
         out <- makeCrunchCubeCalculation(out, cube@dims, "z_score")
@@ -223,8 +223,6 @@ compareDimsPairwise <- function(cube, dim = c("cols", "rows"), baseline) {
         names <- rownames(as.array(cube))
     }
 
-    to_compare <- names[!(names %in% baseline)]
-
     out <- vapply(
         names, function(one_extent) {
             if (one_extent == baseline) {
