@@ -37,7 +37,8 @@ setMethod("[[", c("DatasetCatalog", "numeric"), function(x, i, ...) {
 
 #' @rdname crunch-extract
 #' @export
-setMethod("[[<-", c("DatasetCatalog", "character", "missing", "DatasetTuple"),
+setMethod(
+    "[[<-", c("DatasetCatalog", "character", "missing", "DatasetTuple"),
     function(x, i, j, value) {
         index(x)[[i]] <- value@body
         return(x)
