@@ -77,7 +77,7 @@ mv <- function(x, what, path) {
 #' @export
 mkdir <- function(x, path) {
     ## TODO: add an "after" argument, move created folder there
-    f <- cd(x, path, create = TRUE)
+    cd(x, path, create = TRUE)
     # Refresh without busting cache, in case there was no change
     # If there had been a change, cd() would have busted cache already
     x <- do.call(class(x), crGET(self(x)))
@@ -262,6 +262,8 @@ folder <- function(x) {
             ## If moving a "dataset" into a variable folder, it's a variable
             ## catalog subset. So get the catalog.
             what <- allVariables(what)
+        } else if (is.variable(what)) {
+            what <- self(what)
         }
     }
     if (inherits(what, "ShojiCatalog")) {
