@@ -19,7 +19,12 @@ with_mock_crunch({
         )
         expect_prints(
             cats,
-            get_output(data.frame(id = c(1, 2, -1), name = c("Male", "Female", "No Data"), value = c(1, 2, NA), missing = c(FALSE, FALSE, TRUE)))
+            get_output(
+                data.frame(
+                    id = c(1, 2, -1), name = c("Male", "Female", "No Data"),
+                    value = c(1, 2, NA), missing = c(FALSE, FALSE, TRUE)
+                )
+            )
         )
     })
 
@@ -251,7 +256,12 @@ with_mock_crunch({
         )
     })
     test_that("is.selected assignment methods", {
-        true_body <- '{"categories":[{"id":1,"missing":false,"name":"0.0","numeric_value":0,"selected":true},{"id":2,"missing":false,"name":"1.0","numeric_value":1,"selected":true},{"id":-1,"missing":true,"name":"No Data","numeric_value":null,"selected":true}]}'
+        true_body <- paste0(
+            '{"categories":[{"id":1,"missing":false,"name":"0.0","numeric_value":',
+            '0,"selected":true},{"id":2,"missing":false,"name":"1.0",',
+            '"numeric_value":1,"selected":true},{"id":-1,"missing":true,',
+            '"name":"No Data","numeric_value":null,"selected":true}]}'
+        )
 
         expect_PATCH(
             is.selected(categories(ds$mymrset)) <- c(TRUE, TRUE, TRUE),
@@ -266,7 +276,13 @@ with_mock_crunch({
         expect_PATCH(
             is.selected(categories(ds$mymrset)[2]) <- TRUE,
             "https://app.crunch.io/api/datasets/1/variables/mymrset/",
-            '{"categories":[{"id":1,"missing":false,"name":"0.0","numeric_value":0,"selected":false},{"id":2,"missing":false,"name":"1.0","numeric_value":1,"selected":true},{"id":-1,"missing":true,"name":"No Data","numeric_value":null,"selected":false}]}'
+            paste0(
+                '{"categories":[{"id":1,"missing":false,"name":"0.0",',
+                '"numeric_value":0,"selected":false},{"id":2,"missing":false,',
+                '"name":"1.0","numeric_value":1,"selected":true},{"id":-1,',
+                '"missing":true,"name":"No Data","numeric_value":null,',
+                '"selected":false}]}'
+            )
         )
     })
     test_that("is.selected assignment errors correctly", {
@@ -493,46 +509,46 @@ with_test_authentication({
             expect_false(is.dichotomized(categories(ds$allpets$allpets_2)))
         })
         test_that("Editing array categories affects the subvariables too", {
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc)),
-                c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
+                c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "No Data")
             )
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc$petloc_home)),
-                c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
+                c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "No Data")
             )
             expect_identical(
                 names(table(ds$petloc$petloc_home)),
                 c("Cat", "Dog", "Bird")
             )
             names(categories(ds$petloc))[2] <- "Canine"
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc)),
-                c("Cat", "Canine", "Bird", "Skipped", "Not Asked")
+                c("Cat", "Canine", "Bird", "Skipped", "Not Asked", "No Data")
             )
             expect_identical(
                 names(table(ds$petloc$petloc_home)),
                 c("Cat", "Canine", "Bird")
             )
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc$petloc_home)),
-                c("Cat", "Canine", "Bird", "Skipped", "Not Asked")
+                c("Cat", "Canine", "Bird", "Skipped", "Not Asked", "No Data")
             )
         })
 
         test_that("Reordering array categories", {
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc)),
-                c("Cat", "Canine", "Bird", "Skipped", "Not Asked")
+                c("Cat", "Canine", "Bird", "Skipped", "Not Asked", "No Data")
             )
             categories(ds$petloc) <- rev(categories(ds$petloc))
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc)),
-                c("Not Asked", "Skipped", "Bird", "Canine", "Cat")
+                c("No Data", "Not Asked", "Skipped", "Bird", "Canine", "Cat")
             )
-            expect_identical(
+            expect_identical_temp_nodata(
                 names(categories(ds$petloc$petloc_home)),
-                c("Not Asked", "Skipped", "Bird", "Canine", "Cat")
+                c("No Data", "Not Asked", "Skipped", "Bird", "Canine", "Cat")
             )
         })
         test_that("is.selected method gets and set selection value", {
