@@ -92,9 +92,6 @@ with_test_authentication({
         expect_valid_df_import(ds)
     })
 
-    ## Release and re-lease
-    ds <- releaseAndReload(ds)
-
     test_that("There is an initial version", {
         expect_identical(names(versions(ds)), "initial import")
     })
@@ -137,9 +134,6 @@ with_test_authentication({
         )
     })
 
-    ## Release and re-lease
-    ds <- releaseAndReload(ds)
-
     ## Assert those things again
     test_that("The edits made are still there after releasing", {
         expect_identical(names(na.omit(categories(ds$v4))), c("d", "e"))
@@ -172,18 +166,12 @@ with_test_authentication({
         expect_length(versions(ds), 2)
     })
 
-    ## Release and re-lease
-    ds <- releaseAndReload(ds)
-
     ## Revert to the first version
     ds <- try(restoreVersion(ds, "initial import"))
     test_that("Restoring restored correctly", {
         expect_valid_df_import(ds)
     })
 
-    ## Release and re-lease
-    ds <- releaseAndReload(ds)
-
     test_that("Added variables are really removed by rolling back", {
         ## This was user-reported: Order was reverted but derived
         ## variables persisted, and by assigning an empty order, you can
